from __future__ import annotations
from dataclasses import dataclass
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.response_handler import ResponseHandler
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .....models import error, red_hat_error_representation, service_account_data, service_account_request_data, validation_exception_data
    from .reset_secret import reset_secret_request_builder

class V1ItemRequestBuilder():
    """
    Builds and executes requests for operations under /apis/service_accounts/v1/{id}
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Optional[Union[Dict[str, Any], str]] = None) -> None:
        """
        Instantiates a new V1ItemRequestBuilder and sets the default values.
        Args:
            pathParameters: The raw url or the Url template parameters for the request.
            requestAdapter: The request adapter to use to execute the requests.
        """
        if path_parameters is None:
            raise Exception("path_parameters cannot be undefined")
        if request_adapter is None:
            raise Exception("request_adapter cannot be undefined")
        # Url template to use to build the URL for the current request builder
        self.url_template: str = "{+baseurl}/apis/service_accounts/v1/{id}"

        url_tpl_params = get_path_parameters(path_parameters)
        self.path_parameters = url_tpl_params
        self.request_adapter = request_adapter
    
    async def delete(self,request_configuration: Optional[V1ItemRequestBuilderDeleteRequestConfiguration] = None) -> bytes:
        """
        Delete service account by id. Throws not found exception if the service account is not found or the user does not have access to this service account
        Args:
            requestConfiguration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: bytes
        """
        request_info = self.to_delete_request_information(
            request_configuration
        )
        from .....models import error, red_hat_error_representation, validation_exception_data

        error_mapping: Dict[str, ParsableFactory] = {
            "401": error.Error,
            "404": red_hat_error_representation.RedHatErrorRepresentation,
        }
        if not self.request_adapter:
            raise Exception("Http core is null") 
        return await self.request_adapter.send_primitive_async(request_info, "bytes", error_mapping)
    
    async def get(self,request_configuration: Optional[V1ItemRequestBuilderGetRequestConfiguration] = None) -> Optional[service_account_data.ServiceAccountData]:
        """
        Returns service account by id. Throws not found exception if the service account is not found or the user does not have access to this service account
        Args:
            requestConfiguration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[service_account_data.ServiceAccountData]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        from .....models import error, red_hat_error_representation, validation_exception_data

        error_mapping: Dict[str, ParsableFactory] = {
            "401": error.Error,
            "404": red_hat_error_representation.RedHatErrorRepresentation,
        }
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .....models import service_account_data

        return await self.request_adapter.send_async(request_info, service_account_data.ServiceAccountData, error_mapping)
    
    async def patch(self,body: Optional[service_account_request_data.ServiceAccountRequestData] = None, request_configuration: Optional[V1ItemRequestBuilderPatchRequestConfiguration] = None) -> Optional[service_account_data.ServiceAccountData]:
        """
        Update a service account by id.
        Args:
            body: The request body
            requestConfiguration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[service_account_data.ServiceAccountData]
        """
        if body is None:
            raise Exception("body cannot be undefined")
        request_info = self.to_patch_request_information(
            body, request_configuration
        )
        from .....models import error, red_hat_error_representation, validation_exception_data

        error_mapping: Dict[str, ParsableFactory] = {
            "400": validation_exception_data.ValidationExceptionData,
            "401": error.Error,
            "404": red_hat_error_representation.RedHatErrorRepresentation,
        }
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .....models import service_account_data

        return await self.request_adapter.send_async(request_info, service_account_data.ServiceAccountData, error_mapping)
    
    def to_delete_request_information(self,request_configuration: Optional[V1ItemRequestBuilderDeleteRequestConfiguration] = None) -> RequestInformation:
        """
        Delete service account by id. Throws not found exception if the service account is not found or the user does not have access to this service account
        Args:
            requestConfiguration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation()
        request_info.url_template = self.url_template
        request_info.path_parameters = self.path_parameters
        request_info.http_method = Method.DELETE
        if request_configuration:
            request_info.add_request_headers(request_configuration.headers)
            request_info.add_request_options(request_configuration.options)
        return request_info
    
    def to_get_request_information(self,request_configuration: Optional[V1ItemRequestBuilderGetRequestConfiguration] = None) -> RequestInformation:
        """
        Returns service account by id. Throws not found exception if the service account is not found or the user does not have access to this service account
        Args:
            requestConfiguration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation()
        request_info.url_template = self.url_template
        request_info.path_parameters = self.path_parameters
        request_info.http_method = Method.GET
        request_info.headers["Accept"] = ["application/json"]
        if request_configuration:
            request_info.add_request_headers(request_configuration.headers)
            request_info.add_request_options(request_configuration.options)
        return request_info
    
    def to_patch_request_information(self,body: Optional[service_account_request_data.ServiceAccountRequestData] = None, request_configuration: Optional[V1ItemRequestBuilderPatchRequestConfiguration] = None) -> RequestInformation:
        """
        Update a service account by id.
        Args:
            body: The request body
            requestConfiguration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        if body is None:
            raise Exception("body cannot be undefined")
        request_info = RequestInformation()
        request_info.url_template = self.url_template
        request_info.path_parameters = self.path_parameters
        request_info.http_method = Method.PATCH
        request_info.headers["Accept"] = ["application/json"]
        if request_configuration:
            request_info.add_request_headers(request_configuration.headers)
            request_info.add_request_options(request_configuration.options)
        request_info.set_content_from_parsable(self.request_adapter, "application/json", body)
        return request_info
    
    @property
    def reset_secret(self) -> reset_secret_request_builder.ResetSecretRequestBuilder:
        """
        The resetSecret property
        """
        from .reset_secret import reset_secret_request_builder

        return reset_secret_request_builder.ResetSecretRequestBuilder(self.request_adapter, self.path_parameters)
    
    @dataclass
    class V1ItemRequestBuilderDeleteRequestConfiguration():
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        # Request headers
        headers: Optional[Dict[str, Union[str, List[str]]]] = None

        # Request options
        options: Optional[List[RequestOption]] = None

    
    @dataclass
    class V1ItemRequestBuilderGetRequestConfiguration():
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        # Request headers
        headers: Optional[Dict[str, Union[str, List[str]]]] = None

        # Request options
        options: Optional[List[RequestOption]] = None

    
    @dataclass
    class V1ItemRequestBuilderPatchRequestConfiguration():
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        # Request headers
        headers: Optional[Dict[str, Union[str, List[str]]]] = None

        # Request options
        options: Optional[List[RequestOption]] = None

    

