from __future__ import annotations
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from . import otp

class AuthenticationFactors(AdditionalDataHolder, Parsable):
    def __init__(self,) -> None:
        """
        Instantiates a new AuthenticationFactors and sets the default values.
        """
        # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
        self._additional_data: Dict[str, Any] = {}

        # The otp property
        self._otp: Optional[otp.Otp] = None
    
    @property
    def additional_data(self,) -> Dict[str, Any]:
        """
        Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
        Returns: Dict[str, Any]
        """
        return self._additional_data
    
    @additional_data.setter
    def additional_data(self,value: Dict[str, Any]) -> None:
        """
        Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
        Args:
            value: Value to set for the AdditionalData property.
        """
        self._additional_data = value
    
    @staticmethod
    def create_from_discriminator_value(parse_node: Optional[ParseNode] = None) -> AuthenticationFactors:
        """
        Creates a new instance of the appropriate class based on discriminator value
        Args:
            parseNode: The parse node to use to read the discriminator value and create the object
        Returns: AuthenticationFactors
        """
        if parse_node is None:
            raise Exception("parse_node cannot be undefined")
        return AuthenticationFactors()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        from . import otp

        fields: Dict[str, Callable[[Any], None]] = {
            "otp": lambda n : setattr(self, 'otp', n.get_object_value(otp.Otp)),
        }
        return fields
    
    @property
    def otp(self,) -> Optional[otp.Otp]:
        """
        Gets the otp property value. The otp property
        Returns: Optional[otp.Otp]
        """
        return self._otp
    
    @otp.setter
    def otp(self,value: Optional[otp.Otp] = None) -> None:
        """
        Sets the otp property value. The otp property
        Args:
            value: Value to set for the otp property.
        """
        self._otp = value
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        Args:
            writer: Serialization writer to use to serialize this model
        """
        if writer is None:
            raise Exception("writer cannot be undefined")
        writer.write_object_value("otp", self.otp)
        writer.write_additional_data_value(self.additional_data)
    

